.. include:: ../README.rst

.. toctree::
   :titlesonly:
   :hidden:

   tutorial

.. toctree::
   :caption: User Guide
   :titlesonly:
   :hidden:

   user_guide/installation/index
   user_guide/usage/index
   user_guide/messages/index
   user_guide/configuration/index
   user_guide/checkers/index

.. toctree::
   :caption: Developer Guide
   :maxdepth: 2
   :titlesonly:
   :hidden:

   development_guide/api/index
   development_guide/how_tos/index.rst
   development_guide/technical_reference/index.rst
   development_guide/contributor_guide/index

.. toctree::
   :caption: Additional tools
   :titlesonly:
   :hidden:

   pyreverse
   symilar

.. toctree::
   :caption: Changelog
   :titlesonly:
   :hidden:

   whatsnew/index.rst

.. toctree::
   :caption: Support
   :titlesonly:
   :hidden:

   faq
   contact
